# duo-game-lib

[![CI/CD](https://github.com/game-ai-platform-team/duo-game-lib/actions/workflows/cicd.yml/badge.svg)](https://github.com/game-ai-platform-team/duo-game-lib/actions/workflows/cicd.yml)
[![codecov](https://codecov.io/gh/game-ai-platform-team/duo-game-lib/graph/badge.svg?token=rkxU4I4T0S)](https://codecov.io/gh/game-ai-platform-team/duo-game-lib)

Logic for turn-based duo game.
